==> fwindexmanagement-portlet-2.0.0-20130629.041337-18-sources.jar: org/gcube/portlets/admin/forwardindexportlet/gwt/client/interfaces/ManagementServiceAsync.java <==
package org.gcube.portlets.admin.forwardindexportlet.gwt.client.interfaces;

import java.util.List;
import java.util.Map;

import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.CollectionBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.ForwardIndexTypeBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.IndexBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.IndexTypeBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.MgmtPropertiesBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.RunningInstanceBean;

import com.google.gwt.user.client.rpc.AsyncCallback;

/** An asynchronous interface for the ManagementService following GWT RPC design */
public interface ManagementServiceAsync {

	/**
	 * A method to get all the available FullTextIndexManagement service running instances
	 * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
	 */
	public void getRunningInstances(AsyncCallback<List<RunningInstanceBean>> callback);
	
    /**
     * A method to get all collection beans of collections gathered from DIS
     * (real collections) along with all collection beans of collectionIDs
     * indices are stated to belong to (in their collectionID property) but
     * which do not exist in reality (fake collections)
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getCollections(AsyncCallback<List<CollectionBean>> callback);

    /**
     * A method to get IndexBeans for every Index connected to a specific
     * Collection
     * 
     * @param indexID -
     *            the ID of the Collection to get the Indices from
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getIndices(String collectionID, AsyncCallback<IndexBean[]> callback);

    /**
     * A method to get FullTextIndexTypeBeans for every fulltext index type
     * available in the VO
     * 
     * @return - the list of full text index type IDs
     * @throws Exception - Server side exception as dictated by GWTs RPC framework
     */
    public void getAvailableIndexTypeIDs(AsyncCallback<List<ForwardIndexTypeBean>> callback);

    /**
     * A method used to get information about the ResourceProperties of an Index
     * 
     * @param indexID -
     *            The ID of the Index of which to get the ResourceProperties
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getResourceProperties(String indexID, AsyncCallback<MgmtPropertiesBean> callback);

    /**
     * Creates a new Index for a specified collection
     * 
     * @param indexID -
     *            The ID of the Index to be created. Null if an ID should be
     *            asigned automatically.
     * @param collectionID -
     *            the CollectionID of the Collection the Index should belong to
     * @param keyNames -
     *            the names of the keys of the Index to create
     * @param indexTypeIDs -
     *            the IndexTypes of the keys of the Index to create
     * @param contentType -
     *            the Content Type of the Index to create (usually MetaData or
     *            RealData)
     * @param RIEPR - the EPR of the Running Instance to use for the index creation
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void createIndex(String indexID, String collectionID,
    		String keyNames[], String indexTypeIDs[], String RIEPR, AsyncCallback<String> callback);

    /**
     * Removes/destroys an Index
     * 
     * @param indexID -
     *            The ID of the Index to destroy
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void removeIndex(String indexID, AsyncCallback<Integer> callback);

    /**
     * Retrieves all the indexType descriptions from the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getAllIndexTypes(AsyncCallback<Map<String, IndexTypeBean>> callback);
    
    /**
     * Saves an indexType to the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void saveIndexType(IndexTypeBean idxType, AsyncCallback<String> callback);

    /**
     * Deletes an indexType from the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void deleteIndexType(IndexTypeBean idxType, AsyncCallback<Void> callback);

	void updateIndex(String indexID, String rsLocator,
			AsyncCallback<String> callback);

	void query(String queryString, String indexID,
			AsyncCallback<List<String>> callback);
}

==> fwindexmanagement-portlet-2.1.0-20140203.021021-79-sources.jar: org/gcube/portlets/admin/forwardindexportlet/gwt/client/interfaces/ManagementServiceAsync.java <==
package org.gcube.portlets.admin.forwardindexportlet.gwt.client.interfaces;

import java.util.List;
import java.util.Map;

import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.CollectionBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.ForwardIndexTypeBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.IndexBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.IndexTypeBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.MgmtPropertiesBean;
import org.gcube.portlets.admin.forwardindexportlet.gwt.shared.RunningInstanceBean;

import com.google.gwt.user.client.rpc.AsyncCallback;

/** An asynchronous interface for the ManagementService following GWT RPC design */
public interface ManagementServiceAsync {

	/**
	 * A method to get all the available FullTextIndexManagement service running instances
	 * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
	 */
	public void getRunningInstances(AsyncCallback<List<RunningInstanceBean>> callback);
	
    /**
     * A method to get all collection beans of collections gathered from DIS
     * (real collections) along with all collection beans of collectionIDs
     * indices are stated to belong to (in their collectionID property) but
     * which do not exist in reality (fake collections)
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getCollections(AsyncCallback<List<CollectionBean>> callback);

    /**
     * A method to get IndexBeans for every Index connected to a specific
     * Collection
     * 
     * @param indexID -
     *            the ID of the Collection to get the Indices from
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getIndices(String collectionID, AsyncCallback<IndexBean[]> callback);

    /**
     * A method to get FullTextIndexTypeBeans for every fulltext index type
     * available in the VO
     * 
     * @return - the list of full text index type IDs
     * @throws Exception - Server side exception as dictated by GWTs RPC framework
     */
    public void getAvailableIndexTypeIDs(AsyncCallback<List<ForwardIndexTypeBean>> callback);

    /**
     * A method used to get information about the ResourceProperties of an Index
     * 
     * @param indexID -
     *            The ID of the Index of which to get the ResourceProperties
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getResourceProperties(String indexID, AsyncCallback<MgmtPropertiesBean> callback);

    /**
     * Creates a new Index for a specified collection
     * 
     * @param indexID -
     *            The ID of the Index to be created. Null if an ID should be
     *            asigned automatically.
     * @param collectionID -
     *            the CollectionID of the Collection the Index should belong to
     * @param keyNames -
     *            the names of the keys of the Index to create
     * @param indexTypeIDs -
     *            the IndexTypes of the keys of the Index to create
     * @param contentType -
     *            the Content Type of the Index to create (usually MetaData or
     *            RealData)
     * @param RIEPR - the EPR of the Running Instance to use for the index creation
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void createIndex(String indexID, String collectionID,
    		String keyNames[], String indexTypeIDs[], String RIEPR, AsyncCallback<String> callback);

    void removeIndex(String indexID, String collectionID,
			AsyncCallback<Boolean> callback);

    /**
     * Retrieves all the indexType descriptions from the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void getAllIndexTypes(AsyncCallback<Map<String, IndexTypeBean>> callback);
    
    /**
     * Saves an indexType to the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void saveIndexType(IndexTypeBean idxType, AsyncCallback<String> callback);

    /**
     * Deletes an indexType from the IS.
     * 
     * @param callback -
     *            the AsyncCallback used to handle the asynchronous completion
     *            of the remote method, in accordance with the GWT RPC framework
     */
    public void deleteIndexType(IndexTypeBean idxType, AsyncCallback<Void> callback);

	void updateIndex(String indexID, String rsLocator,
			AsyncCallback<String> callback);

	void query(String queryString, String indexID,
			AsyncCallback<List<String>> callback);
}
